# **TerCol**

#### _A completely useless library for terminal styling._

# **Why should I use this for terminal styling?**

- Whenever you feel insane.

# **What features does this library have?**

- Everything other libraries have.

# **How do I use this?**
    import tercol
    print(tercol.red('Red text'))
    print(tercol.blue('Blue text'))
    print(tercol.rgb(255, 215, 0, 'Gold text using RGB'))
    print(tercol.hex('#ffd700', 'Gold text using HEX'))

that's all
bye